==> nextcloud-29.0.12.tgz: nextcloud/apps/encryption/l10n/it.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Manca la password della chiave di ripristino",
    "Please repeat the recovery key password" : "Ripeti la password della chiave di ripristino",
    "Repeated recovery key password does not match the provided recovery key password" : "La password della chiave di ripristino ripetuta non corrisponde alla password della chiave di ripristino fornita",
    "Recovery key successfully enabled" : "Chiave di ripristino abilitata correttamente",
    "Could not enable recovery key. Please check your recovery key password!" : "Impossibile abilitare la chiave di ripristino. Verifica la password della chiave di ripristino.",
    "Recovery key successfully disabled" : "Chiave di ripristino disabilitata correttamente",
    "Could not disable recovery key. Please check your recovery key password!" : "Impossibile disabilitare la chiave di ripristino. Verifica la password della chiave di ripristino.",
    "Missing parameters" : "Parametri mancanti",
    "Please provide the old recovery password" : "Fornisci la vecchia password di ripristino",
    "Please provide a new recovery password" : "Fornisci una nuova password di ripristino",
    "Please repeat the new recovery password" : "Ripeti la nuova password di ripristino",
    "Password successfully changed." : "Password modificata correttamente.",
    "Could not change the password. Maybe the old password was not correct." : "Impossibile cambiare la password. Forse la vecchia password non era corretta.",
    "Recovery Key disabled" : "Chiave di ripristino disabilitata",
    "Recovery Key enabled" : "Chiave di ripristino abilitata",
    "Could not enable the recovery key, please try again or contact your administrator" : "Impossibile abilitare la chiave di ripristino, prova ancora o contatta il tuo amministratore",
    "Could not update the private key password." : "Impossibile aggiornare la password della chiave privata.",
    "The old password was not correct, please try again." : "La vecchia password non era corretta, prova di nuovo.",
    "The current log-in password was not correct, please try again." : "La password di accesso attuale non era corretta, prova ancora.",
    "Private key password successfully updated." : "Password della chiave privata aggiornata correttamente.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Chiave privata non valida per l'applicazione di cifratura. Aggiorna la password della chiave privata nelle impostazioni personali per ripristinare l'accesso ai tuoi file cifrati.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "L'applicazione di cifratura è abilitata, ma le chiavi non sono state inizializzate. Disconnettiti ed effettua nuovamente l'accesso.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Abilita la cifratura lato server nelle impostazioni di amministrazione per utilizzare il modulo di cifratura.",
    "Encryption app is enabled and ready" : "L'applicazione Cifratura è abilitata e pronta",
    "Bad Signature" : "Firma non valida",
    "Missing Signature" : "Firma mancante",
    "one-time password for server-side-encryption" : "password monouso per la cifratura lato server",
    "Encryption password" : "Password di cifratura",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Impossibile decifrare questo file, probabilmente è un file condiviso. Chiedi al proprietario del file di condividere nuovamente il file con te.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Impossibile leggere questo file, probabilmente è un file condiviso. Chiedi al proprietario del file di condividere nuovamente il file con te.",
    "Default encryption module" : "Modulo di cifratura predefinito",
    "Default encryption module for server-side encryption" : "Modulo di cifratura predefinito per la cifratura lato server",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "L'applicazione di cifratura è abilitata, ma le chiavi non sono state inizializzate, disconnettiti ed effettua nuovamente l'accesso",
    "Encrypt the home storage" : "Cifra l'archiviazione principale",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "L'abilitazione di questa opzione cifra tutti i file memorizzati sull'archiviazione principale, altrimenti saranno cifrati solo i file sull'archiviazione esterna.",
    "Enable recovery key" : "Abilita chiave di ripristino",
    "Disable recovery key" : "Disabilita chiave di ripristino",
    "Recovery key password" : "Password della chiave di ripristino",
    "Repeat recovery key password" : "Ripeti la password della chiave di ripristino",
    "Change recovery key password:" : "Cambia la password della chiave di ripristino:",
    "Old recovery key password" : "Vecchia password della chiave di ripristino",
    "New recovery key password" : "Nuova password della chiave di ripristino",
    "Repeat new recovery key password" : "Ripeti la nuova password della chiave di ripristino",
    "Change Password" : "Modifica password",
    "Basic encryption module" : "Modulo di cifratura base",
    "Your private key password no longer matches your log-in password." : "La password della chiave privata non corrisponde più alla password di accesso.",
    "Set your old private key password to your current log-in password:" : "Imposta la vecchia password della chiave privata sull'attuale password di accesso:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Se non ricordi la vecchia password puoi chiedere al tuo amministratore di recuperare i file.",
    "Old log-in password" : "Vecchia password di accesso",
    "Current log-in password" : "Password di accesso attuale",
    "Update Private Key Password" : "Aggiorna la password della chiave privata",
    "Enable password recovery:" : "Abilita il ripristino della password:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "L'abilitazione di questa opzione ti consentirà di accedere nuovamente ai file cifrati in caso di perdita della password",
    "Enabled" : "Abilitata",
    "Disabled" : "Disabilitata"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.12p0.tgz: nextcloud/apps/encryption/l10n/it.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Manca la password della chiave di ripristino",
    "Please repeat the recovery key password" : "Ripeti la password della chiave di ripristino",
    "Repeated recovery key password does not match the provided recovery key password" : "La password della chiave di ripristino ripetuta non corrisponde alla password della chiave di ripristino fornita",
    "Recovery key successfully enabled" : "Chiave di ripristino abilitata correttamente",
    "Could not enable recovery key. Please check your recovery key password!" : "Impossibile abilitare la chiave di ripristino. Verifica la password della chiave di ripristino.",
    "Recovery key successfully disabled" : "Chiave di ripristino disabilitata correttamente",
    "Could not disable recovery key. Please check your recovery key password!" : "Impossibile disabilitare la chiave di ripristino. Verifica la password della chiave di ripristino.",
    "Missing parameters" : "Parametri mancanti",
    "Please provide the old recovery password" : "Fornisci la vecchia password di ripristino",
    "Please provide a new recovery password" : "Fornisci una nuova password di ripristino",
    "Please repeat the new recovery password" : "Ripeti la nuova password di ripristino",
    "Password successfully changed." : "Password modificata correttamente.",
    "Could not change the password. Maybe the old password was not correct." : "Impossibile cambiare la password. Forse la vecchia password non era corretta.",
    "Recovery Key disabled" : "Chiave di ripristino disabilitata",
    "Recovery Key enabled" : "Chiave di ripristino abilitata",
    "Could not enable the recovery key, please try again or contact your administrator" : "Impossibile abilitare la chiave di ripristino, prova ancora o contatta il tuo amministratore",
    "Could not update the private key password." : "Impossibile aggiornare la password della chiave privata.",
    "The old password was not correct, please try again." : "La vecchia password non era corretta, prova di nuovo.",
    "The current log-in password was not correct, please try again." : "La password di accesso attuale non era corretta, prova ancora.",
    "Private key password successfully updated." : "Password della chiave privata aggiornata correttamente.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Chiave privata non valida per l'applicazione di cifratura. Aggiorna la password della chiave privata nelle impostazioni personali per ripristinare l'accesso ai tuoi file cifrati.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "L'applicazione di cifratura è abilitata, ma le chiavi non sono state inizializzate. Disconnettiti ed effettua nuovamente l'accesso.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Abilita la cifratura lato server nelle impostazioni di amministrazione per utilizzare il modulo di cifratura.",
    "Encryption app is enabled and ready" : "L'applicazione Cifratura è abilitata e pronta",
    "Bad Signature" : "Firma non valida",
    "Missing Signature" : "Firma mancante",
    "one-time password for server-side-encryption" : "password monouso per la cifratura lato server",
    "Encryption password" : "Password di cifratura",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Impossibile decifrare questo file, probabilmente è un file condiviso. Chiedi al proprietario del file di condividere nuovamente il file con te.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Impossibile leggere questo file, probabilmente è un file condiviso. Chiedi al proprietario del file di condividere nuovamente il file con te.",
    "Default encryption module" : "Modulo di cifratura predefinito",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "L'applicazione di cifratura è abilitata, ma le chiavi non sono state inizializzate, disconnettiti ed effettua nuovamente l'accesso",
    "Encrypt the home storage" : "Cifra l'archiviazione principale",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "L'abilitazione di questa opzione cifra tutti i file memorizzati sull'archiviazione principale, altrimenti saranno cifrati solo i file sull'archiviazione esterna.",
    "Enable recovery key" : "Abilita chiave di ripristino",
    "Disable recovery key" : "Disabilita chiave di ripristino",
    "Recovery key password" : "Password della chiave di ripristino",
    "Repeat recovery key password" : "Ripeti la password della chiave di ripristino",
    "Change recovery key password:" : "Cambia la password della chiave di ripristino:",
    "Old recovery key password" : "Vecchia password della chiave di ripristino",
    "New recovery key password" : "Nuova password della chiave di ripristino",
    "Repeat new recovery key password" : "Ripeti la nuova password della chiave di ripristino",
    "Change Password" : "Modifica password",
    "Basic encryption module" : "Modulo di cifratura base",
    "Your private key password no longer matches your log-in password." : "La password della chiave privata non corrisponde più alla password di accesso.",
    "Set your old private key password to your current log-in password:" : "Imposta la vecchia password della chiave privata sull'attuale password di accesso:",
    "Old log-in password" : "Vecchia password di accesso",
    "Current log-in password" : "Password di accesso attuale",
    "Update Private Key Password" : "Aggiorna la password della chiave privata",
    "Enable password recovery:" : "Abilita il ripristino della password:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "L'abilitazione di questa opzione ti consentirà di accedere nuovamente ai file cifrati in caso di perdita della password",
    "Enabled" : "Abilitata",
    "Disabled" : "Disabilitata",
    "Default encryption module for server-side encryption" : "Modulo di cifratura predefinito per la cifratura lato server"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
